==> ovirt-engine-3.3.1.tar.gz: backend/manager/modules/common/src/main/java/org/ovirt/engine/core/common/queries/GetExistingStorageDomainListParameters.java <==
package org.ovirt.engine.core.common.queries;

import org.ovirt.engine.core.common.businessentities.StorageDomainType;
import org.ovirt.engine.core.common.businessentities.StorageFormatType;
import org.ovirt.engine.core.common.businessentities.StorageType;
import org.ovirt.engine.core.compat.Guid;

public class GetExistingStorageDomainListParameters extends VdsIdParametersBase {
    private static final long serialVersionUID = 7478078947370484916L;
    private StorageType privateStorageType;

    public StorageType getStorageType() {
        return privateStorageType;
    }

    private void setStorageType(StorageType value) {
        privateStorageType = value;
    }

    private StorageDomainType privateStorageDomainType;

    public StorageDomainType getStorageDomainType() {
        return privateStorageDomainType;
    }

    private void setStorageDomainType(StorageDomainType value) {
        privateStorageDomainType = value;
    }

    private String privatePath;

    public String getPath() {
        return privatePath;
    }

    private void setPath(String value) {
        privatePath = value;
    }

    private StorageFormatType storageFormatType;

    public StorageFormatType getStorageFormatType() {
        return storageFormatType;
    }

    private void setStorageFormatType(StorageFormatType storageFormatType) {
        this.storageFormatType = storageFormatType;
    }

    public GetExistingStorageDomainListParameters(Guid vdsId, StorageType storageType,
            StorageDomainType storageDomainType, String path) {
        this(vdsId, storageType, storageDomainType, path, null);
    }

    public GetExistingStorageDomainListParameters(Guid vdsId, StorageType storageType,
            StorageDomainType storageDomainType, String path, StorageFormatType storageFormatType) {
        super(vdsId);
        setStorageType(storageType);
        setStorageDomainType(storageDomainType);
        setPath(path);
        setStorageFormatType(storageFormatType);
    }

    public GetExistingStorageDomainListParameters() {
        this(null, StorageType.UNKNOWN, StorageDomainType.Master, null);
    }
}

==> ovirt-engine-4.4.5.11.tar.gz: backend/manager/modules/common/src/main/java/org/ovirt/engine/core/common/queries/GetExistingStorageDomainListParameters.java <==
package org.ovirt.engine.core.common.queries;

import org.ovirt.engine.core.common.businessentities.StorageDomainType;
import org.ovirt.engine.core.common.businessentities.StorageFormatType;
import org.ovirt.engine.core.common.businessentities.storage.StorageType;
import org.ovirt.engine.core.compat.Guid;

public class GetExistingStorageDomainListParameters extends IdQueryParameters {
    private static final long serialVersionUID = 7478078947370484916L;
    private StorageType privateStorageType;

    public StorageType getStorageType() {
        return privateStorageType;
    }

    private void setStorageType(StorageType value) {
        privateStorageType = value;
    }

    private StorageDomainType privateStorageDomainType;

    public StorageDomainType getStorageDomainType() {
        return privateStorageDomainType;
    }

    private void setStorageDomainType(StorageDomainType value) {
        privateStorageDomainType = value;
    }

    private String privatePath;

    public String getPath() {
        return privatePath;
    }

    private void setPath(String value) {
        privatePath = value;
    }

    private StorageFormatType storageFormatType;

    public StorageFormatType getStorageFormatType() {
        return storageFormatType;
    }

    private void setStorageFormatType(StorageFormatType storageFormatType) {
        this.storageFormatType = storageFormatType;
    }

    public GetExistingStorageDomainListParameters(Guid vdsId, StorageType storageType,
            StorageDomainType storageDomainType, String path) {
        this(vdsId, storageType, storageDomainType, path, null);
    }

    public GetExistingStorageDomainListParameters(Guid vdsId, StorageType storageType,
            StorageDomainType storageDomainType, String path, StorageFormatType storageFormatType) {
        super(vdsId);
        setStorageType(storageType);
        setStorageDomainType(storageDomainType);
        setPath(path);
        setStorageFormatType(storageFormatType);
    }

    public GetExistingStorageDomainListParameters() {
        this(null, StorageType.UNKNOWN, StorageDomainType.Master, null);
    }
}
